# Compatible with Python 2.7 and Python 3.x
from __future__ import print_function, division, absolute_import

"""Fake SQL utilities for loading CSV data as database-like records.

This module provides functions to load CSV data and return it in formats
that simulate SQL query results, compatible with both Python 2.7 and 3.x.
"""

from pandas import read_csv


def load_csv_as_records(csv_file_path):
    # type: (str) -> list
    """Load CSV data and return as list of tuples (simulating SQL records).
    
    This function reads a CSV file using pandas and converts each row
    into a tuple, creating a list structure similar to SQL query results.
    
    Args:
        csv_file_path: Path to the CSV file to be loaded.
        
    Returns:
        List of tuples where each tuple represents a data row.
        
    Raises:
        FileNotFoundError: If the specified CSV file does not exist.
        pandas.errors.EmptyDataError: If the CSV file is empty.
        pandas.errors.ParserError: If the CSV file is malformed.
        
    Example:
        records = load_csv_as_records('data/sample.csv')
        # Returns: [('John', 25, 'Engineer'), ('Jane', 30, 'Manager')]
    """
    try:
        # Load CSV data into pandas DataFrame
        data_frame = read_csv(csv_file_path)
        
        # Convert DataFrame to list of tuples (simulating SQL records)
        record_list = [tuple(row) for row in data_frame.to_numpy()]
        
        return record_list
        
    except Exception as e:
        # Re-raise with more context for debugging
        raise Exception('Failed to load CSV file {}: {}'.format(
            csv_file_path, str(e)))


# Legacy function alias for backward compatibility
select_data = load_csv_as_records  # Deprecated: use load_csv_as_records