# Compatible with Python 2.7 and Python 3.x
from __future__ import print_function, division, absolute_import

"""Notification utilities for sending messages via various platforms.

This module provides functions for sending notifications through different
services like Telegram, compatible with both Python 2.7 and 3.x.
"""

from requests import post, Response


def send_telegram_message(token, message, chat_id):
    # type: (str, str, str) -> Response
    """Send a message via Telegram Bot API.
    
    Args:
        token: Telegram bot token for authentication.
        message: Text message to send (supports HTML formatting).
        chat_id: Target chat ID or username to send message to.
        
    Returns:
        Response object from the Telegram API request.
        
    Raises:
        requests.RequestException: If the HTTP request fails.
        
    Example:
        response = send_telegram_message(
            token='your_bot_token',
            message='<b>Hello World!</b>',
            chat_id='@your_channel'
        )
    """
    # Build API URL using string formatting instead of f-strings
    api_url = 'https://api.telegram.org/bot{}/sendMessage'.format(token)
    
    # Prepare request payload
    request_payload = {
        "text": message,
        "parse_mode": "html",
        "chat_id": chat_id
    }
    
    # Set appropriate headers for JSON request
    request_headers = {
        "accept": "application/json",
        "content-type": "application/json"
    }
    
    # Send POST request to Telegram API
    response = post(api_url, json=request_payload, headers=request_headers)
    return response


# Legacy function alias for backward compatibility
telegram = send_telegram_message  # Deprecated: use send_telegram_message