# Compatible with Python 2.7 and Python 3.x
from __future__ import print_function, division, absolute_import

"""Decorator utilities for function timing and performance monitoring.

This module provides decorators for measuring function execution time,
compatible with both Python 2.7 and 3.x.
"""

from functools import wraps
from time import time, sleep, strftime, gmtime


def measure_execution_time(func):
    # type: (callable) -> callable
    """Decorator to measure and display function execution time.
    
    This decorator calculates the total execution time of a function
    and prints it in HH:MM:SS format. Includes a 1-second delay
    after function execution for timing accuracy.
    
    Args:
        func: The function to be decorated.
        
    Returns:
        Wrapped function that measures execution time.
        
    Example:
        @measure_execution_time
        def slow_function():
            time.sleep(2)
            return "done"
            
        result = slow_function()  # Prints execution time
    """
    @wraps(func)
    def execution_timer(*args, **kwargs):
        # type: (*any, **any) -> any
        """Wrapper function that measures execution time."""
        # Record start time
        start_time = time()
        
        # Execute the original function
        function_result = func(*args, **kwargs)
        
        # Add delay for timing accuracy
        sleep(1)
        
        # Record end time and calculate duration
        end_time = time()
        elapsed_seconds = end_time - start_time
        
        # Format and display execution time
        formatted_time = strftime("%H:%M:%S", gmtime(elapsed_seconds))
        print('Execution time for function {} is {}'.format(
            func.__name__, formatted_time))
        
        return function_result
    
    return execution_timer


# Legacy decorator alias for backward compatibility
calculate_time = measure_execution_time  # Deprecated: use measure_execution_time 